@@ -59,7 +59,6 @@ class RDFLib(HandlerPlugin):
         orig = Graph(self.store, identifier=ident)
         new = Graph(identifier=ident)
         new += orig
-        orig.rollback()
         return new
     def __setitem__(self, k, g):
         assert isinstance(g, _Graph)
@@ -67,20 +66,17 @@ class RDFLib(HandlerPlugin):
         old.remove((None, None, None))
         for statement in g.triples((None, None, None)):
             old.add(statement)
-        old.commit()
         if hasattr(self.store, "sync"):
             self.store.sync()
     def __delitem__(self, k):
         old = Graph(self.store, identifier=get_identifier(k))
         old.remove((None, None, None))
-        old.commit()
         if hasattr(self.store, "sync"):
             self.store.sync()
 
     def append(self, g):
         old = Graph(self.store, identifier=g.identifier)
         old += g
-        old.commit()
         if hasattr(self.store, "sync"):
             self.store.sync()
                                     
@@ -94,6 +90,11 @@ class RDFLib(HandlerPlugin):
             g = ConjunctiveGraph(self.store)
             return g.query(*av, **kw)
 
+    def commit(self):
+        self.store.commit()
+    def rollback(self):
+        self.store.rollback()
+        
 class FourStore(RDFLib):
     """
     Use of this back-end requires the `py4s`_ bindings to `4store`_.
